@@ -47,6 +47,9 @@ use overload (
 	'^'   =>   \&bxor,
 	'|'   =>   \&bior,
 
+    '<<' =>    \&blshift,
+    '>>' =>    \&brshift,
+
 	'%'   =>   \&op_mod,
 	'**'  =>   sub { $_[2] ? op_pow($_[1], $_[0]) : op_pow($_[0], $_[1]) },
 	'*'   =>   \&op_mul,
@@ -62,7 +65,7 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '2.08';
+our $VERSION = '2.09';
 
 sub AUTOLOAD {
 	# This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -134,10 +137,18 @@ sub add {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Math::GMP - High speed arbitrary size integer math
 
+=head1 VERSION
+
+version 2.09
+
 =head1 SYNOPSIS
 
   use Math::GMP;
@@ -222,6 +233,24 @@ argument.
 Calculates the bit-wise OR of its two arguments and modifies the first
 argument.
 
+=head2 blshift
+
+  $x = Math::GMP->new(0b11);
+  my $result = $x->blshift(4, 0);
+  # $result = 0b11 << 4 = 0b110000
+
+Calculates the bit-wise left-shift of its two arguments and returns the
+result. Second argument is swap.
+
+=head2 brshift
+
+  $x = Math::GMP->new(0b11001);
+  my $result = $x->brshift(3, 0);
+  # $result = 0b11001 << 3 = 0b11
+
+Calculates the bit-wise right-shift of its two arguments and returns the
+result. Second argument is swap.
+
 =head2 bgcd
 
   $x = Math::GMP->new(6);
@@ -322,8 +351,144 @@ L<Math::BigInt::Pari> or L<Math::BigInt::BitVect>.
 =head1 AUTHOR
 
 Chip Turner <chip@redhat.com>, based on the old Math::BigInt by Mark Biggar
-and Ilya Zakharevich.  Further extensive work provided by Tels 
+and Ilya Zakharevich.  Further extensive work provided by Tels
 <tels@bloodgate.com>.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2000 by James H. Turner.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://rt.cpan.org/Public/Dist/Display.html?Name=Math-GMP or by email to
+bug-math-fft@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Math::GMP
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Math-GMP>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Math-GMP>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Math-GMP>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Math-GMP>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Math-GMP>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Math-GMP>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Math-GMP>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/M/Math-GMP>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Math-GMP>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Math::GMP>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-math-gmp at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Math-GMP>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/turnstep/perl-Math-GMP>
+
+  git clone https://github.com/turnstep/perl-Math-GMP.git
 
 =cut
